@@ -2,10 +2,12 @@
 
 import asyncio
 from typing import Any, AsyncGenerator, List
+
 import pytest
 from pypck.connection import PchkConnectionManager
-from pypck.module import ModuleConnection
+from pypck.helpers import PYPCK_TASKS
 from pypck.lcn_addr import LcnAddr
+from pypck.module import ModuleConnection
 from pypck.pck_commands import PckGenerator
 
 from .fake_pchk import PchkServer
@@ -73,6 +75,7 @@ async def pypck_client() -> AsyncGenerator[PchkConnectionManager, None]:
     )
     yield pcm
     await pcm.async_close()
+    assert len(PYPCK_TASKS) == 0
 
 
 @pytest.fixture
